==> catberry-oauth2-client-2.0.8.tgz: package/lib/helpers/uriHelper.js <==
/*
 * catberry-oauth
 *
 * Copyright (c) 2014 Denis Rechkunov and project contributors.
 *
 * catberry-oauth's license follows:
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge,
 * publish, distribute, sublicense, and/or sell copies of the Software,
 * and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 * This license applies to all parts of catberry-oauth that are not externally
 * maintained libraries.
 */

'use strict';

module.exports = {
	/**
	 * Gets path for token resource.
	 * @param {String} endpointName Name of endpoint.
	 * @returns {String}
	 */
	getPath: function (endpointName) {
		return '/' + endpointName;
	},
	/**
	 * Gets path for token refresh resource.
	 * @param {String} endpointName Name of endpoint.
	 * @returns {String}
	 */
	getRefreshPath: function (endpointName) {
		return '/' + endpointName + '/refresh';
	},
	/**
	 * Gets path for token remove resource.
	 * @param {String} endpointName Name of endpoint.
	 * @returns {String}
	 */
	getRemovePath: function (endpointName) {
		return '/' + endpointName + '/remove';
	}
};

==> catberry-oauth2-client-2.0.10.tgz: package/lib/helpers/uriHelper.js <==
/*
 * catberry-oauth
 *
 * Copyright (c) 2014 Denis Rechkunov and project contributors.
 *
 * catberry-oauth's license follows:
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge,
 * publish, distribute, sublicense, and/or sell copies of the Software,
 * and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 * This license applies to all parts of catberry-oauth that are not externally
 * maintained libraries.
 */

'use strict';

module.exports = {
	/**
	 * Gets path for token resource.
	 * @param {string} endpointName Name of endpoint.
	 * @returns {string} URI path string.
	 */
	getPath: function (endpointName) {
		return '/' + endpointName;
	},
	/**
	 * Gets path for token refresh resource.
	 * @param {string} endpointName Name of endpoint.
	 * @returns {string} URI path string.
	 */
	getRefreshPath: function (endpointName) {
		return '/' + endpointName + '/refresh';
	},
	/**
	 * Gets path for token remove resource.
	 * @param {string} endpointName Name of endpoint.
	 * @returns {string} URI path string.
	 */
	getRemovePath: function (endpointName) {
		return '/' + endpointName + '/remove';
	}
};
